Struct PrecompileVerifierRegistry
pub struct PrecompileVerifierRegistry { /* private fields */ }Expand description
Registry of precompile verifiers.
This struct maintains a map of event IDs to their corresponding event names and verifiers. It is used to verify precompile requests during proof verification.
Implementations
impl PrecompileVerifierRegistry
impl PrecompileVerifierRegistry
pub fn new() -> PrecompileVerifierRegistry
pub fn new() -> PrecompileVerifierRegistry
Creates a new empty precompile verifiers registry.
pub fn with_verifier(
self,
event_name: &EventName,
verifier: Arc<dyn PrecompileVerifier>,
) -> PrecompileVerifierRegistry
pub fn with_verifier( self, event_name: &EventName, verifier: Arc<dyn PrecompileVerifier>, ) -> PrecompileVerifierRegistry
Returns a new registry that includes the supplied verifier in addition to existing ones.
pub fn merge(&mut self, other: &PrecompileVerifierRegistry)
pub fn merge(&mut self, other: &PrecompileVerifierRegistry)
Merges another registry into this one, overwriting any conflicting event IDs with the other registry’s verifiers.
pub fn requests_transcript(
&self,
requests: &[PrecompileRequest],
) -> Result<PrecompileTranscript, PrecompileVerificationError>
pub fn requests_transcript( &self, requests: &[PrecompileRequest], ) -> Result<PrecompileTranscript, PrecompileVerificationError>
Verifies all precompile requests and returns the resulting precompile transcript state after recording all commitments.
Errors
Returns a PrecompileVerificationError if:
- No verifier is registered for a request’s event ID
- A verifier fails to verify its request