verify_with_precompiles

Function verify_with_precompiles 

pub fn verify_with_precompiles(
    program_info: ProgramInfo,
    stack_inputs: StackInputs,
    stack_outputs: StackOutputs,
    proof: ExecutionProof,
    precompile_verifiers: &PrecompileVerifierRegistry,
) -> Result<(u32, PrecompileTranscriptDigest), VerificationError>
Identical to verify, with additional verification of any precompile requests made during the VM execution. The resulting aggregated precompile commitment is returned, which can be compared against the commitment computed by the VM.

Returns

Returns a tuple (security_level, aggregated_commitment) where:

  • security_level: The security level (in bits) of the verified proof
  • aggregated_commitment: A Word containing the final aggregated commitment to all precompile requests, computed by recomputing and recording each precompile commitment in a transcript. This value is the finalized digest of the recomputed precompile transcript.

Errors

Returns any error produced by verify, as well as any errors resulting from precompile verification.